% Auto-generated chapter 1 for malik
% Hadiths in this chapter: 31

\hadithdefcmd{malik}{1}{قَالَ حَدَّثَنِي يَحْيَى بْنُ يَحْيَى اللَّيْثِيُّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخَّرَ الصَّلاَةَ يَوْمًا فَدَخَلَ عَلَيْهِ عُرْوَةُ بْنُ الزُّبَيْرِ فَأَخْبَرَهُ أَنَّ الْمُغِيرَةَ بْنَ شُعْبَةَ أَخَّرَ الصَّلاَةَ يَوْمًا وَهُوَ بِالْكُوفَةِ فَدَخَلَ عَلَيْهِ أَبُو مَسْعُودٍ الأَنْصَارِيُّ فَقَالَ مَا هَذَا يَا مُغِيرَةُ أَلَيْسَ قَدْ عَلِمْتَ أَنَّ جِبْرِيلَ نَزَلَ فَصَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ بِهَذَا أُمِرْتُ ‏"‏ ‏.‏ فَقَالَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ اعْلَمْ مَا تُحَدِّثُ بِهِ يَا عُرْوَةُ أَوَ إِنَّ جِبْرِيلَ هُوَ الَّذِي أَقَامَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَقْتَ الصَّلاَةِ قَالَ عُرْوَةُ كَذَلِكَ كَانَ بَشِيرُ بْنُ أَبِي مَسْعُودٍ الأَنْصَارِيُّ يُحَدِّثُ عَنْ أَبِيهِ ‏.‏\hadithno{1}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{He said, "Yahya ibn Yahya al-Laythi related to me from Malik ibn Anas from Ibn Shihab that one day Umar ibn Abdal-Aziz delayed the prayer. Urwa ibn az-Zubayr came and told him that al-Mughira ibn Shuba had delayed the prayer one day while he was in Kufa and Abu Masud al- Ansari had come to him and said, 'What's this, Mughira? Don't you know that the angel Jibril came down and prayed and the Messenger of Allah, may Allah bless him and grant him peace, prayed.' Then he prayed again, and the Messenger of Allah, may Allah bless him and grant him peace, prayed. Then he prayed again, and the Messenger of Allah, may Allah bless him and grant him peace, prayed. Then he prayed again, and the Messenger of Allah, may Allah bless him and grant him peace, prayed. Then he prayed again, and the Messenger of Allah, may Allah bless him and grant him peace, prayed. Then Jibril said, 'This is what you have been ordered to do.' Umar ibn Abd al-Aziz said, 'Be sure of what you relate, Urwa. Was it definitely Jibril who established the time of the prayer for the Messenger of Allah?' " Urwa said, "That's how it was related to Bashir ibn Abi Masud al-Ansari by his father}}
\hadithdefcmd{malik}{2}{قَالَ عُرْوَةُ وَلَقَدْ حَدَّثَتْنِي عَائِشَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ وَالشَّمْسُ فِي حُجْرَتِهَا قَبْلَ أَنْ تَظْهَرَ ‏.‏\hadithno{2}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Urwa said that A'isha, the wife of the Prophet, may Allah bless him and grant him peace used to pray asr while the sunlight was pouring into her room, before the sun itself had become visible (i.e. because it was still high in the sky)}}
\hadithdefcmd{malik}{3}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ عَنْ وَقْتِ صَلاَةِ الصُّبْحِ قَالَ فَسَكَتَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَ مِنَ الْغَدِ صَلَّى الصُّبْحَ حِينَ طَلَعَ الْفَجْرُ ثُمَّ صَلَّى الصُّبْحَ مِنَ الْغَدِ بَعْدَ أَنْ أَسْفَرَ ثُمَّ قَالَ ‏"‏ أَيْنَ السَّائِلُ عَنْ وَقْتِ الصَّلاَةِ ‏"‏ ‏.‏ قَالَ هَا أَنَا ذَا يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ مَا بَيْنَ هَذَيْنِ وَقْتٌ ‏"‏ ‏.‏\hadithno{3}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Ata ibn Yasar said, "A man came to the Messenger of Allah, may Allah bless him and grant him peace, and asked him about the time of the subh prayer. The Messenger of Allah, may Allah bless him and grant him peace, did not answer him, but in the morning he prayed subh at first light. The following morning he prayed subh when it was much lighter, and then said, 'Where is the man who was asking about the time of the prayer?' The man replied, 'Here I am, Messenger of Allah.' He said,'The time is between these two}}
\hadithdefcmd{malik}{4}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُصَلِّي الصُّبْحَ فَيَنْصَرِفُ النِّسَاءُ مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ مَا يُعْرَفْنَ مِنَ الْغَلَسِ ‏.‏\hadithno{4}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Amra bint Abd ar-Rahman that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The Messenger of Allah, may Allah bless him and grant him peace, used to pray subh and the women would leave wrapped in their garments and they could not yet be recognised in the darkness}}
\hadithdefcmd{malik}{5}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، وَعَنْ بُسْرِ بْنِ سَعِيدٍ، وَعَنِ الأَعْرَجِ، كُلُّهُمْ يُحَدِّثُونَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنَ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَ الصُّبْحَ وَمَنْ أَدْرَكَ رَكْعَةً مِنَ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَ الْعَصْرَ ‏"‏ ‏.‏\hadithno{5}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar and from Busr ibn Said and from al-Araj-all of whom related it from Abu Hurayra - that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever manages to do a raka of subh before the sun has risen has done subh in time, and whoever manages to do a raka of asr before the sun has set has done asr in time}}
\hadithdefcmd{malik}{6}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَتَبَ إِلَى عُمَّالِهِ إِنَّ أَهَمَّ أَمْرِكُمْ عِنْدِي الصَّلاَةُ فَمَنْ حَفِظَهَا وَحَافَظَ عَلَيْهَا حَفِظَ دِينَهُ وَمَنْ ضَيَّعَهَا فَهُوَ لِمَا سِوَاهَا أَضْيَعُ ‏.‏ ثُمَّ كَتَبَ أَنْ صَلُّوا الظُّهْرَ إِذَا كَانَ الْفَىْءُ ذِرَاعًا إِلَى أَنْ يَكُونَ ظِلُّ أَحَدِكُمْ مِثْلَهُ وَالْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ بَيْضَاءُ نَقِيَّةٌ قَدْرَ مَا يَسِيرُ الرَّاكِبُ فَرْسَخَيْنِ أَوْ ثَلاَثَةً قَبْلَ غُرُوبِ الشَّمْسِ وَالْمَغْرِبَ إِذَا غَرَبَتِ الشَّمْسُ وَالْعِشَاءَ إِذَا غَابَ الشَّفَقُ إِلَى ثُلُثِ اللَّيْلِ فَمَنْ نَامَ فَلاَ نَامَتْ عَيْنُهُ فَمَنْ نَامَ فَلاَ نَامَتْ عَيْنُهُ فَمَنْ نَامَ فَلاَ نَامَتْ عَيْنُهُ وَالصَّبْحَ وَالنُّجُومُ بَادِيَةٌ مُشْتَبِكَةٌ ‏.‏\hadithno{6}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Nafi', the mawla of Abdullah ibn Umar, that Umar ibn al-Khattab wrote to his governors saying, "The most important of your affairs in my view is the prayer. Whoever protects it and observes it carefully is protecting his deen, while whoever is negligent about it will be even more negligent about other things." Then he added, "Pray dhuhr any time from when the afternoon shade is the length of your forearm until the length of your shadow matches your height. Pray asr when the sun is still pure white, so that a rider can travel two or three farsakhs before the sun sets. Pray maghrib when the sun has set. Pray isha any time from when the redness in the western sky has disappeared until a third of the night has passed - and a person who sleeps, may he have no rest, a person who sleeps, may he have no rest. And pray subh when all the stars are visible and like a haze in the sky}}
\hadithdefcmd{malik}{7}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلٍ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَتَبَ إِلَى أَبِي مُوسَى أَنْ صَلِّ الظُّهْرَ، إِذَا زَاغَتِ الشَّمْسُ وَالْعَصْرَ وَالشَّمْسُ بَيْضَاءُ نَقِيَّةٌ قَبْلَ أَنْ يَدْخُلَهَا صُفْرَةٌ وَالْمَغْرِبَ إِذَا غَرَبَتِ الشَّمْسُ وَأَخِّرِ الْعِشَاءَ مَا لَمْ تَنَمْ وَصَلِّ الصُّبْحَ وَالنُّجُومُ بَادِيَةٌ مُشْتَبِكَةٌ وَاقْرَأْ فِيهَا بِسُورَتَيْنِ طَوِيلَتَيْنِ مِنَ الْمُفَصَّلِ ‏.‏\hadithno{7}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik, from his uncle Abu Suhayl from his father that Umar ibn al-Khattab wrote to Abu Musa saying that he should pray dhuhr when the sun had started to decline, asr when the sun was still pure white before any yellowness had entered it maghrib when the sun had set, and to delay isha as long as he did not sleep, and to pray subh when the stars were all visible and like a haze in the sky and to read in it two long suras from the mufassal}}
\hadithdefcmd{malik}{8}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَتَبَ إِلَى أَبِي مُوسَى الأَشْعَرِيِّ أَنْ صَلِّ الْعَصْرَ، وَالشَّمْسُ، بَيْضَاءُ نَقِيَّةٌ قَدْرَ مَا يَسِيرُ الرَّاكِبُ ثَلاَثَةَ فَرَاسِخَ وَأَنْ صَلِّ الْعِشَاءَ مَا بَيْنَكَ وَبَيْنَ ثُلُثِ اللَّيْلِ فَإِنْ أَخَّرْتَ فَإِلَى شَطْرِ اللَّيْلِ وَلاَ تَكُنْ مِنَ الْغَافِلِينَ ‏.‏\hadithno{8}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Umar ibn al-Khattab wrote to Abu Musa al-Ashari that he should pray asr when the sun was still pure white so that a man could ride three farsakhs (before maghrib) and that he should pray Isha during the first third of the night, or, if he delayed it, then up until the middle of the night, and he warned him not to be forgetful}}
\hadithdefcmd{malik}{9}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، مَوْلَى أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ سَأَلَ أَبَا هُرَيْرَةَ عَنْ وَقْتِ الصَّلاَةِ فَقَالَ أَبُو هُرَيْرَةَ أَنَا أُخْبِرُكَ صَلِّ الظُّهْرَ إِذَا كَانَ ظِلُّكَ مِثْلَكَ وَالْعَصْرَ إِذَا كَانَ ظِلُّكَ مِثْلَيْكَ وَالْمَغْرِبَ إِذَا غَرَبَتِ الشَّمْسُ وَالْعِشَاءَ مَا بَيْنَكَ وَبَيْنَ ثُلُثِ اللَّيْلِ وَصَلِّ الصُّبْحَ بِغَبَشٍ ‏.‏ يَعْنِي الْغَلَسَ ‏.‏\hadithno{9}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Ziyad that Abdullah ibn Rafi, the mawla of Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, asked Abu Hurayra about the time of the prayer. Abu Hurayra said, "Let me tell you. Pray dhuhr when the length of your shadow matches your height, asr when your shadow is twice your height, maghrib when the sun has set, isha in the first third of the night, and subh in the very first light of dawn," i.e. when the dawn has definitely come}}
\hadithdefcmd{malik}{10}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ كُنَّا نُصَلِّي الْعَصْرَ ثُمَّ يَخْرُجُ الإِنْسَانُ إِلَى بَنِي عَمْرِو بْنِ عَوْفٍ فَيَجِدُهُمْ يُصَلُّونَ الْعَصْرَ ‏.‏\hadithno{10}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha that Anas ibn Malik said, "We would pray asr and anyone who then went to the Bani Amr ibn Awf would find them praying asr}}
\hadithdefcmd{malik}{11}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ كُنَّا نُصَلِّي الْعَصْرَ ثُمَّ يَذْهَبُ الذَّاهِبُ إِلَى قُبَاءٍ فَيَأْتِيهِمْ وَالشَّمْسُ مُرْتَفِعَةٌ ‏.‏\hadithno{11}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Anas ibn Malik said, "We would pray asr and anyone who then went to Quba would arrive there while the sun was still high}}
\hadithdefcmd{malik}{12}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ قَالَ مَا أَدْرَكْتُ النَّاسَ إِلاَّ وَهُمْ يُصَلُّونَ الظُّهْرَ بِعَشِيٍّ ‏.‏\hadithno{12}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that al Qasim ibn Muhammad said, "None of the companions that I met prayed dhuhr until well after noon,"(i.e.until when the sun had lost its fierceness)}}
\hadithdefcmd{malik}{13}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كُنْتُ أَرَى طِنْفِسَةً لِعَقِيلِ بْنِ أَبِي طَالِبٍ يَوْمَ الْجُمُعَةِ تُطْرَحُ إِلَى جِدَارِ الْمَسْجِدِ الْغَرْبِيِّ فَإِذَا غَشِيَ الطِّنْفِسَةَ كُلَّهَا ظِلُّ الْجِدَارِ خَرَجَ عُمَرُ بْنُ الْخَطَّابِ وَصَلَّى الْجُمُعَةَ - قَالَ مَالِكٌ وَالِدُ أَبِي سُهَيْلٍ - ثُمَّ نَرْجِعُ بَعْدَ صَلاَةِ الْجُمُعَةِ فَنَقِيلُ قَائِلَةَ الضَّحَاءِ ‏.‏\hadithno{13}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from his uncle Abu Suhayl ibn Malik that his father said, "I used to see a carpet belonging to Aqil ibn Abi Talib spread out on the day of jumua up to the west wall of the mosque. When the shadow of the wall covered the whole carpet, Umar ibn al-Khattab would come out and pray the jumua prayer." Malik, Abu Suhayl's father, added, "We would then return after the jumua prayer and take our midday sleep}}
\hadithdefcmd{malik}{14}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنِ ابْنِ أَبِي سَلِيطٍ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، صَلَّى الْجُمُعَةَ بِالْمَدِينَةِ وَصَلَّى الْعَصْرَ بِمَلَلٍ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ لِلتَّهْجِيرِ وَسُرْعَةِ السَّيْرِ ‏.‏\hadithno{14}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Amr ibn Yahya ibn Yahya al- Mazini from Ibn Abi Salit that Uthman ibn Affan prayed jumua in Madina and asr in Malal (a place seventeen miles from Madina). Malik commented, "That was by praying jumua just past midday and then travelling fast}}
\hadithdefcmd{malik}{15}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنَ الصَّلاَةِ فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{15}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Salama ibn Abdar-Rahman from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said "Whoever catches a raka of the prayer has caught the prayer}}
\hadithdefcmd{malik}{16}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ بْنِ الْخَطَّابِ، كَانَ يَقُولُ إِذَا فَاتَتْكَ الرَّكْعَةُ فَقَدْ فَاتَتْكَ السَّجْدَةُ ‏.‏\hadithno{16}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar ibn al-Khattab used to say, "If the ruku has passed you by, so has the sajda}}
\hadithdefcmd{malik}{17}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، وَزَيْدَ بْنَ ثَابِتٍ، كَانَا يَقُولاَنِ مَنْ أَدْرَكَ الرَّكْعَةَ فَقَدْ أَدْرَكَ السَّجْدَةَ ‏.‏\hadithno{17}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar and Zayd ibn Thabit used to say, "Whoever catches the raka`ah has caught the sajda}}
\hadithdefcmd{malik}{18}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا هُرَيْرَةَ، كَانَ يَقُولُ مَنْ أَدْرَكَ الرَّكْعَةَ فَقَدْ أَدْرَكَ السَّجْدَةَ وَمَنْ فَاتَهُ قِرَاءَةُ أُمِّ الْقُرْآنِ فَقَدْ فَاتَهُ خَيْرٌ كَثِيرٌ ‏.‏\hadithno{18}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abu Hurayra used to say, "Whoever catches the ruku has caught the sajda and whoever misses the recitation of the umm al-Qur'an has missed much good}}
\hadithdefcmd{malik}{19}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ دُلُوكُ الشَّمْسِ مَيْلُهَا ‏.‏\hadithno{19}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "Duluk ash-shams begins from when the sun passes the meridian}}
\hadithdefcmd{malik}{20}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، قَالَ أَخْبَرَنِي مُخْبِرٌ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَ يَقُولُ دُلُوكُ الشَّمْسِ إِذَا فَاءَ الْفَىْءُ وَغَسَقُ اللَّيْلِ اجْتِمَاعُ اللَّيْلِ وَظُلْمَتُهُ ‏.‏\hadithno{20}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Da'ud ibn al-Husayn said that someone had told him Abdullah ibn Abbas used to say, "Duluk ash-shams begins from when the sun passes the meridian. Ghasaq al-layl is the gathering of the night and its darkness}}
\hadithdefcmd{malik}{21}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي تَفُوتُهُ صَلاَةُ الْعَصْرِ كَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏ ‏.‏\hadithno{21}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "If someone misses the asr prayer it is as if he has suffered a great misfortune in his family and wealth}}
\hadithdefcmd{malik}{22}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، انْصَرَفَ مِنْ صَلاَةِ الْعَصْرِ فَلَقِيَ رَجُلاً لَمْ يَشْهَدِ الْعَصْرَ فَقَالَ عُمَرُ مَا حَبَسَكَ عَنْ صَلاَةِ الْعَصْرِ فَذَكَرَ لَهُ الرَّجُلُ عُذْرًا فَقَالَ عُمَرُ طَفَّفْتَ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَيُقَالُ لِكُلِّ شَىْءٍ وَفَاءٌ وَتَطْفِيفٌ ‏.‏\hadithno{22}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that once Umar ibn al-Khattab left after doing the asr prayer and met a man who had not been there. Umar asked him what had kept him from the prayer and eventhough the man gave a good reason, Umar said, "You have given yourself short measure." Yahya added that Malik commented, "It is said that everything has a short measure and a full measure}}
\hadithdefcmd{malik}{23}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ كَانَ يَقُولُ إِنَّ الْمُصَلِّيَ لَيُصَلِّي الصَّلاَةَ وَمَا فَاتَهُ وَقْتُهَا وَلَمَا فَاتَهُ مِنْ وَقْتِهَا أَعْظَمُ - أَوْ أَفْضَلُ - مِنْ أَهْلِهِ وَمَالِهِ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ مَنْ أَدْرَكَ الْوَقْتَ وَهُوَ فِي سَفَرٍ فَأَخَّرَ الصَّلاَةَ سَاهِيًا أَوْ نَاسِيًا حَتَّى قَدِمَ عَلَى أَهْلِهِ أَنَّهُ إِنْ كَانَ قَدِمَ عَلَى أَهْلِهِ وَهُوَ فِي الْوَقْتِ فَلْيُصَلِّ صَلاَةَ الْمُقِيمِ وَإِنْ كَانَ قَدْ قَدِمَ وَقَدْ ذَهَبَ الْوَقْتُ فَلْيُصَلِّ صَلاَةَ الْمُسَافِرِ لأَنَّهُ إِنَّمَا يَقْضِي مِثْلَ الَّذِي كَانَ عَلَيْهِ ‏.‏ قَالَ مَالِكٌ وَهَذَا الأَمْرُ هُوَ الَّذِي أَدْرَكْتُ عَلَيْهِ النَّاسَ وَأَهْلَ الْعِلْمِ بِبَلَدِنَا ‏.‏ وَقَالَ مَالِكٌ الشَّفَقُ الْحُمْرَةُ الَّتِي فِي الْمَغْرِبِ فَإِذَا ذَهَبَتِ الْحُمْرَةُ فَقَدْ وَجَبَتْ صَلاَةُ الْعِشَاءِ وَخَرَجْتَ مِنْ وَقْتِ الْمَغْرِبِ ‏.‏\hadithno{23}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik thatYahya ibn Said used to say, "Even if someone manages to pray before the time of the prayer has passed, the time that has passed him by is more important, or better, than his family and wealth." Yahya said that Malik said, "If the time for a prayer comes and a traveller delays a prayer through neglect or forgetfulness until he reaches his family, he should do that prayer in full if he arrives within the time. But if he arrives when the time has past, he should do the travelling prayer. That way he only repays what he owes." Malik said, "This is what I have found the people and men of knowledge doing in our community." Malik explained that shafaq was the redness in the sky after the sun had set, and said, "When the redness has gone then the isha prayer is due and you have left the time of maghrib}}
\hadithdefcmd{malik}{24}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أُغْمِيَ عَلَيْهِ فَذَهَبَ عَقْلُهُ فَلَمْ يَقْضِ الصَّلاَةَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ فِيمَا نَرَى - وَاللَّهُ أَعْلَمُ - أَنَّ الْوَقْتَ قَدْ ذَهَبَ فَأَمَّا مَنْ أَفَاقَ فِي الْوَقْتِ فَإِنَّهُ يُصَلِّي ‏.‏\hadithno{24}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that one time Abdullah ibn Umar fainted and lost his senses and he did not make up the prayer. Malik commented, "We consider that that was because, and Allah knows best, the time had passed. Someone who recovers within the time has to pray}}
\hadithdefcmd{malik}{25}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ قَفَلَ مِنْ خَيْبَرَ أَسْرَى حَتَّى إِذَا كَانَ مِنْ آخِرِ اللَّيْلِ عَرَّسَ وَقَالَ لِبِلاَلٍ ‏"‏ اكْلأْلَنَا الصُّبْحَ ‏"‏ ‏.‏ وَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ وَكَلأَ بِلاَلٌ مَا قُدِّرَ لَهُ ثُمَّ اسْتَنَدَ إِلَى رَاحِلَتِهِ وَهُوَ مُقَابِلُ الْفَجْرِ فَغَلَبَتْهُ عَيْنَاهُ فَلَمْ يَسْتَيْقِظْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلاَ بِلاَلٌ وَلاَ أَحَدٌ مِنَ الرَّكْبِ حَتَّى ضَرَبَتْهُمُ الشَّمْسُ فَفَزِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ بِلاَلٌ يَا رَسُولَ اللَّهِ أَخَذَ بِنَفْسِي الَّذِي أَخَذَ بِنَفْسِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْتَادُوا ‏"‏ ‏.‏ فَبَعَثُوا رَوَاحِلَهُمْ وَاقْتَادُوا شَيْئًا ثُمَّ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلاَلاً فَأَقَامَ الصَّلاَةَ فَصَلَّى بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم الصُّبْحَ ثُمَّ قَالَ حِينَ قَضَى الصَّلاَةَ ‏"‏ مَنْ نَسِيَ الصَّلاَةَ فَلْيُصَلِّهَا إِذَا ذَكَرَهَا فَإِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏أَقِمِ الصَّلاَةَ لِذِكْرِي ‏\}‏ ‏"‏ ‏.‏\hadithno{25}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab that the Messenger of Allah, may Allah bless him and grant him peace, travelled by night on the way back from Khaybar.Towards the end of the night he stopped for a rest and told Bilal to stay awake to keep watch for the subh prayer. The Messenger of Allah, may Allah bless him and grant him peace, and his companions slept. Bilal stayed on guard as long as was decreed for him and then he leant against his riding camel facing the direction of the dawn and sleep overcame him and neither he nor the Messenger of Allah nor any of the party woke up until the sun's rays had struck them. The Messenger of Allah, may Allah bless him and grant him peace, was alarmed. Bilal excused himself, saying, "Messenger of Allah! The One who took your self was the One who took myself. "The Messenger of Allah, may Allah bless him and grant him peace, ordered the party to move on and so they roused thei r mounts and rode on a short distance. The Messenger of Allah, may Allah bless him and grant him peace, ordered Bilal to give the iqama and then led them in the subh prayer. When he had finished he said, "Anyone who forgets a prayer should pray it when he remembers. Allah theBlessed and Exalted says in His book, 'Establish the prayer to remember Me}}
\hadithdefcmd{malik}{26}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّهُ قَالَ عَرَّسَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً بِطَرِيقِ مَكَّةَ وَوَكَّلَ بِلاَلاً أَنْ يُوقِظَهُمْ لِلصَّلاَةِ فَرَقَدَ بِلاَلٌ وَرَقَدُوا حَتَّى اسْتَيْقَظُوا وَقَدْ طَلَعَتْ عَلَيْهِمُ الشَّمْسُ فَاسْتَيْقَظَ الْقَوْمُ وَقَدْ فَزِعُوا فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَرْكَبُوا حَتَّى يَخْرُجُوا مِنْ ذَلِكَ الْوَادِي وَقَالَ ‏"‏ إِنَّ هَذَا وَادٍ بِهِ شَيْطَانٌ ‏"‏ ‏.‏ فَرَكِبُوا حَتَّى خَرَجُوا مِنْ ذَلِكَ الْوَادِي ثُمَّ أَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَنْزِلُوا وَأَنْ يَتَوَضَّئُوا وَأَمَرَ بِلاَلاً أَنْ يُنَادِيَ بِالصَّلاَةِ أَوْ يُقِيمَ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ ثُمَّ انْصَرَفَ إِلَيْهِمْ وَقَدْ رَأَى مِنْ فَزَعِهِمْ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّ اللَّهَ قَبَضَ أَرْوَاحَنَا وَلَوْ شَاءَ لَرَدَّهَا إِلَيْنَا فِي حِينٍ غَيْرِ هَذَا فَإِذَا رَقَدَ أَحَدُكُمْ عَنِ الصَّلاَةِ أَوْ نَسِيَهَا ثُمَّ فَزِعَ إِلَيْهَا فَلْيُصَلِّهَا كَمَا كَانَ يُصَلِّيهَا فِي وَقْتِهَا ‏"‏ ‏.‏ ثُمَّ الْتَفَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أَبِي بَكْرٍ فَقَالَ ‏"‏ إِنَّ الشَّيْطَانَ أَتَى بِلاَلاً وَهُوَ قَائِمٌ يُصَلِّي فَأَضْجَعَهُ فَلَمْ يَزَلْ يُهَدِّئُهُ كَمَا يُهَدَّأُ الصَّبِيُّ حَتَّى نَامَ ‏"‏ ‏.‏ ثُمَّ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِلاَلاً فَأَخْبَرَ بِلاَلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم مِثْلَ الَّذِي أَخْبَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا بَكْرٍ فَقَالَ أَبُو بَكْرٍ أَشْهَدُ أَنَّكَ رَسُولُ اللَّهِ ‏.‏\hadithno{26}\hadithgrade{Salim al-Hilali: Hasan Lighairihi}\hadithtrans{Yahya related to me from Malik that Zayd ibn Aslam said, "The Messenger of Allah, may Allah bless him and grant him peace, stopped for a rest one night on the way to Makka and appointed Bilal to wake them up for the prayer. Bilal slept and everyone else slept and none of them woke up until the sun had risen. When they did wake up they were all alarmed. The Messenger of Allah, may Allah bless him and grant him peace, ordered them to ride out of the valley, saying that there was a shaytan in it. So they rode out of the valley and the Messenger of Allah, may Allah bless him and grant him peace, ordered them to dismount and do wudu and he told Bilal either to call the prayer or to give the iqama. The Messenger of Allah, may Allah bless him and grant him peace, then led them in the prayer. Noticing their uneasiness, he went to them and said, 'O people! Allah seized our spirits (arwah) and if He had wished He would have returned them to us at a time other than this. So if you sleep through the time for a prayer or forget it and then are anxious about it, pray it as if you were praying it in its time.' The Messenger of Allah, may Allah bless him and grant him peace, turned to Abu Bakr and said, 'Shaytan came to Bilal when he was standing in prayer and made him lie down and lulled him to sleep like a small boy.' The Messenger of Allah, may Allah bless him and grant him peace, then called Bilal and told him the same as he had told Abu Bakr. Abu Bakr declared, 'I bear witness that you are the Messenger of Allah}}
\hadithdefcmd{malik}{27}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ فَإِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ اشْتَكَتِ النَّارُ إِلَى رَبِّهَا فَقَالَتْ يَا رَبِّ أَكَلَ بَعْضِي بَعْضًا ‏.‏ فَأَذِنَ لَهَا بِنَفَسَيْنِ فِي كُلِّ عَامٍ نَفَسٍ فِي الشِّتَاءِ وَنَفَسٍ فِي الصَّيْفِ ‏"‏ ‏.‏\hadithno{27}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Scorching heat is a part of the blast of Jahannam. So, when the heat is fierce, delay the prayer until it gets cooler." He added in explanation, "The Fire complained to its Lord and said, 'My Lord, part of me has eaten another part,' so He allowed it two breaths in every year, a breath in winter and a breath in summer}}
\hadithdefcmd{malik}{28}{وَحَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَعَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏ وَذَكَرَ ‏"‏ أَنَّ النَّارَ اشْتَكَتْ إِلَى رَبِّهَا فَأَذِنَ لَهَا فِي كُلِّ عَامٍ بِنَفَسَيْنِ نَفَسٍ فِي الشِّتَاءِ وَنَفَسٍ فِي الصَّيْفِ ‏"‏ ‏.‏\hadithno{28}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to us from Abdullah ibn Yazid the mawla of al-Aswad ibn Sufyan, from Abu Salama ibn Abd ar-Rahman from Muhammad ibn Abd ar-Rahman ibn Thawban from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When the heat is fierce delay the prayer until it gets cooler, for scorching heat is a part of the blast of Jahannam." He added, "The Fire complained to its Lord, so He allowed it two breaths in each year, a breath in winter and a breath in summer}}
\hadithdefcmd{malik}{29}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{29}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When the heat is fierce, wait until it gets cooler before you do the prayer, for scorching heat is from the blast of Jahannam}}
\hadithdefcmd{malik}{30}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ فَلاَ يَقْرُبْ مَسَاجِدَنَا يُؤْذِينَا بِرِيحِ الثُّومِ ‏"‏ ‏.‏\hadithno{30}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab that the Messenger of Allah, may Allah bless him and grant him peace, said, "Anyone who eats this plant should not come near our mosques. The smell of the garlic will offend us}}
\hadithdefcmd{malik}{31}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْمُجَبَّرِ، أَنَّهُ كَانَ يَرَى سَالِمَ بْنَ عَبْدِ اللَّهِ إِذَا رَأَى الإِنْسَانَ يُغَطِّي فَاهُ وَهُوَ يُصَلِّي جَبَذَ الثَّوْبَ عَنْ فِيهِ جَبْذًا شَدِيدًا حَتَّى يَنْزِعَهُ عَنْ فِيهِ ‏.‏\hadithno{31}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Mujabbar that he used to see Salim ibn Abdullah pull the cloth away fiercely from the mouth of any man he saw covering his mouth while praying}}
